#version 330

/**
 * This first defined out variable of the fragment shader defines
 * with which color the fragment is rendered
 */
out vec4 fragment_color;

/**
 * The texture of the mesh which is used for rendering:
 */
uniform sampler2D materialColorTexture;

/** Should the texture be used? */
uniform bool useMaterialColorTexture;

/** The color of the mesh: */
uniform vec3 materialColor;

/** The shininess of the mesh: */
uniform float materialShininess;

/** Position of this fragment in camera space. */
in vec3 position_from_vs;

/** Normal of this fragment in camera space. */
in vec3 normal_from_vs;

/** Texture coordinate from the vertex shader. */
in vec2 texCoord_from_vs;

/** Ambient light color (I_amb): */
vec3 ambientColor = vec3(0.05, 0.05, 0.05);

// Structure for point lights:
struct Light {
    vec3 position;
    vec3 color;
    float range;
};

// Predefine 100 point lights (since arrays must have a fixed size in GLSL):
uniform Light lights[100];

// Number of lights that should actually be used:
uniform int lightNum;

/**
 * The main function of the fragment shader, which is executed
 * for every fragment.
 */
void main()
{
    // Define parameter k:
    vec3 k = materialColor;

    // Multiply the materialColorTexture with k, if it's available:s
    if(useMaterialColorTexture){
        k *= texture2D(materialColorTexture, texCoord_from_vs).rgb;
    }

    // TODO
    // (1a) Calculate I_out and write that value (instead of k) into fragment_color.
    // (1b) Implement the given attenuation function.
    // ...

    fragment_color = vec4(k, 1);
}